@@ -1,19 +1,19 @@
 ;;   Copyright (C) 2003 Dale Mellor
 ;; 
-;;   This program is free software; you can redistribute it and/or modify
-;;   it under the terms of the GNU General Public License as published by
-;;   the Free Software Foundation; either version 2, or (at your option)
+;;   This file is part of GNU mcron.
+;;
+;;   GNU mcron is free software: you can redistribute it and/or modify it under
+;;   the terms of the GNU General Public License as published by the Free
+;;   Software Foundation, either version 3 of the License, or (at your option)
 ;;   any later version.
-;; 
-;;   This program is distributed in the hope that it will be useful,
-;;   but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;   GNU General Public License for more details.
-;; 
-;;   You should have received a copy of the GNU General Public License
-;;   along with this program; if not, write to the Free Software
-;;   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
-;;   USA.
+;;
+;;   GNU mcron is distributed in the hope that it will be useful, but WITHOUT
+;;   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+;;   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+;;   more details.
+;;
+;;   You should have received a copy of the GNU General Public License along
+;;   with GNU mcron.  If not, see <http://www.gnu.org/licenses/>.
 
 
 
@@ -106,12 +106,10 @@
                         (edit     (single-char #\e) (value #f))
                         (list     (single-char #\l) (value #f))
                         (remove   (single-char #\r) (value #f))))
-                     (else `((schedule (single-char #\s)
-                                       (value optional)
-                                       (predicate ;; Added by Sergey Poznyakoff.
+                     (else `((schedule (single-char #\s) (value #t)
+                                       (predicate
                                         ,(lambda (value)
-                                           (or (eq? value #t)
-                                               (string->number value)))))
+                                           (string->number value))))
                              (daemon   (single-char #\d) (value #f))
                              (noetc    (single-char #\n) (value #f))
                              (stdin    (single-char #\i) (value #t)
@@ -157,8 +155,7 @@ extensions.\n
 \n
   -v, --version             Display version\n
   -h, --help                Display this help message\n
-  -s, --schedule[=COUNT]    Display the next COUNT jobs (default 8) that\n
-                              will be run by mcron\n
+  -sN, --schedule[=]N       Display the next N jobs that will be run by mcron\n
   -d, --daemon              Immediately detach the program from the terminal and\n
                               run as a daemon process\n
   -i, --stdin=(guile|vixie) Format of data passed as standard input or\n
@@ -171,8 +168,7 @@ reading all the information in the users' crontabs and in /etc/crontab.\n
 \n
   -v, --version             Display version\n
   -h, --help                Display this help message\n
-  -s, --schedule[=COUNT]    Display the next COUNT jobs (default 8) that\n
-                              will be run by cron\n
+  -sN, --schedule[=]N       Display the next N jobs that will be run by cron\n
   -n, --noetc               Do not check /etc/crontab for updates (HIGHLY\n
                               RECOMMENDED).")
   
@@ -287,15 +283,16 @@ Report bugs to " config-package-bugreport ".\n
 (define guile-file-regexp (make-regexp "\\.gui(le)?$"))
 (define vixie-file-regexp (make-regexp "\\.vix(ie)?$"))
 
-(define (process-user-file file-path)
+(define (process-user-file file-path . assume-guile)
   (cond ((string=? file-path "-")
                (if (string=? (option-ref options 'stdin "guile") "vixie")
                    (read-vixie-port (current-input-port))
                    (eval-string (stdin->string))))
-        ((regexp-exec guile-file-regexp file-path)
-               (load file-path))
+        ((or (not (null? assume-guile))
+             (regexp-exec guile-file-regexp file-path))
+         (load file-path))
         ((regexp-exec vixie-file-regexp file-path)
-               (read-vixie-file file-path))))
+         (read-vixie-file file-path))))
 
 
 
@@ -372,7 +369,7 @@ Report bugs to " config-package-bugreport ".\n
   ((mcron) (if (null? (option-ref options '() '()))
                 (process-files-in-user-directory)
                 (for-each (lambda (file-path)
-                            (process-user-file file-path))
+                            (process-user-file file-path #t))
                           (option-ref options '() '()))))
   
   ((cron) (process-files-in-system-directory)
@@ -403,9 +400,7 @@ option.\n")
 ;; count is some positive integer.
 
 (and-let* ((count (option-ref options 'schedule #f)))
-          (set! count (if (eq? count #t)
-                          8
-                          (string->number count)))
+          (set! count (string->number count))
           (display (get-schedule (if (<= count 0) 1 count)))
           (quit))
     
